@@ -20,9 +20,13 @@ log = logging.getLogger(__name__)
 
 
 def decode_event_parameters(data, topics, abi, anonymous):
+
+    # making copy to avoid modifying of the original list
+    amended_topics = topics.copy()
+
     # for anonymous events shift the list of topics
     if anonymous:
-        topics.insert(0, None)
+        amended_topics.insert(0, None)
 
     parameters_abi = abi.parameters if abi else []
 
@@ -40,11 +44,11 @@ def decode_event_parameters(data, topics, abi, anonymous):
             parameter_name = parameter.parameter_name
             parameter_type = parameter.parameter_type
             # assumption that topic parameters can be only static
-            if len(topics) > i + 1:
+            if len(amended_topics) > i + 1:
                 raw_parameter = (
-                    topics[i + 1]
-                    if isinstance(topics[i + 1], str)
-                    else topics[i + 1].hex()
+                    amended_topics[i + 1]
+                    if isinstance(amended_topics[i + 1], str)
+                    else amended_topics[i + 1].hex()
                 )
                 if not parameter_type:
                     parameter_value = raw_parameter
@@ -70,13 +74,15 @@ def decode_event_parameters(data, topics, abi, anonymous):
 
     else:
 
-        for i, parameter in enumerate(topics[1:]):
-            if not topics[i + 1]:
+        for i, parameter in enumerate(amended_topics[1:]):
+            if not amended_topics[i + 1]:
                 break
             parameter_name = ""
             parameter_type = "unknown"
             parameter_value = (
-                topics[i + 1] if isinstance(topics[i + 1], str) else topics[i + 1].hex()
+                amended_topics[i + 1]
+                if isinstance(amended_topics[i + 1], str)
+                else amended_topics[i + 1].hex()
             )
 
             topic_parameters[i] = Argument(
@@ -99,11 +105,13 @@ def decode_event_parameters(data, topics, abi, anonymous):
         ni = nd = 0
         for i in range(len(parameters_abi)):
             if idx_parameters[i]:
-                event_parameters.append(topic_parameters[ni])
-                ni += 1
+                if len(topic_parameters) > ni:
+                    event_parameters.append(topic_parameters[ni])
+                    ni += 1
             else:
-                event_parameters.append(data_parameters[nd])
-                nd += 1
+                if len(data_parameters) > nd:
+                    event_parameters.append(data_parameters[nd])
+                    nd += 1
     else:
         for _, parameter in topic_parameters.items():
             event_parameters.append(parameter)
@@ -113,14 +121,23 @@ def decode_event_parameters(data, topics, abi, anonymous):
     return event_parameters
 
 
-def decode_function_parameters(input_data, output, abi, status=True):
+def decode_function_parameters(input_data, output, abi, status=True, strip_signature=True):
+
+    if strip_signature and len(input_data) >= 10:
+        stripped_input_data = input_data[10:]
+    else:
+        stripped_input_data = input_data[2:]
+
     if abi:
-        input_parameters, _ = decode_struct(input_data[10:], abi.inputs)
+        if len(abi.inputs) == 1 and abi.inputs[0].parameter_type == 'raw':
+            input_parameters = [dict(name=abi.inputs[0].parameter_name, type='bytes', value=input_data)]
+        else:
+            input_parameters, _ = decode_struct(stripped_input_data, abi.inputs)
         for i, parameter in enumerate(input_parameters):
             input_parameters[i] = Argument(**parameter)
-    elif input_data[10:]:
+    elif stripped_input_data:
         input_parameters = [
-            Argument(name="call_data", type="bytes", value="0x" + input_data[10:])
+            Argument(name="call_data", type="bytes", value="0x" + stripped_input_data)
         ]
     else:
         input_parameters = []
@@ -135,9 +152,12 @@ def decode_function_parameters(input_data, output, abi, status=True):
                 log.warning("Warning: missing output data...")
                 output_parameters = []
             else:
-                output_parameters, _ = decode_struct(output[2:], abi.outputs)
-                for i, parameter in enumerate(output_parameters):
-                    output_parameters[i] = Argument(**parameter)
+                if len(abi.outputs) == 1 and abi.outputs[0].parameter_type == 'raw':
+                    output_parameters = [dict(name=abi.outputs[0].parameter_name, type='bytes', value=output)]
+                else:
+                    output_parameters, _ = decode_struct(output[2:], abi.outputs)
+                    for i, parameter in enumerate(output_parameters):
+                        output_parameters[i] = Argument(**parameter)
         elif output != "0x":
             output_parameters = [
                 Argument(name="output_data", type="bytes", value=output)
