@@ -29,6 +29,7 @@ from ethtx.providers.web3_provider import Web3Provider
 from ethtx.semantics.protocols_router import amend_contract_semantics
 from ethtx.semantics.standards.erc20 import ERC20_FUNCTIONS, ERC20_EVENTS
 from ethtx.semantics.standards.erc721 import ERC721_FUNCTIONS, ERC721_EVENTS
+from ethtx.semantics.solidity.precompiles import precompiles
 
 
 class SemanticsRepository:
@@ -54,6 +55,7 @@ class SemanticsRepository:
         return tmp_records
 
     def _read_stored_semantics(self, address: str, chain_id: str):
+
         def decode_parameter(_parameter):
             components_semantics = []
             for component in _parameter["components"]:
@@ -69,6 +71,9 @@ class SemanticsRepository:
 
             return decoded_parameter
 
+        if not address:
+            return None
+
         ZERO_HASH = "0xc5d2460186f7233c927e7db2dcc703c0e500b653ca82273b7bfad8045d85a470"
 
         raw_address_semantics = self.database.get_address_semantics(chain_id, address)
@@ -161,10 +166,14 @@ class SemanticsRepository:
     @lru_cache(maxsize=128)
     def get_semantics(self, chain_id: str, address: str) -> Optional[AddressSemantics]:
 
+        if not address:
+            return None
+
         ZERO_HASH = "0xc5d2460186f7233c927e7db2dcc703c0e500b653ca82273b7bfad8045d85a470"
 
         address_semantics = self._read_stored_semantics(address, chain_id)
         if not address_semantics:
+
             # try to read the semantics form the Etherscan provider
             provider = self._web3provider
             code_hash = provider.get_code_hash(address)
@@ -239,7 +248,7 @@ class SemanticsRepository:
                     chain_id, address, address, False, contract_semantics, None, None
                 )
 
-            self.update_semantics(address_semantics)
+        self.update_semantics(address_semantics)
 
         # amend semantics with locally stored updates
         amend_contract_semantics(address_semantics.contract)
@@ -250,6 +259,9 @@ class SemanticsRepository:
         standard = None
         standard_semantics = None
 
+        if not address:
+            return standard, standard_semantics
+
         if all(erc20_event in events for erc20_event in ERC20_EVENTS) and all(
             erc20_function in functions for erc20_function in ERC20_FUNCTIONS
         ):
@@ -272,6 +284,10 @@ class SemanticsRepository:
 
     @lru_cache(maxsize=128)
     def get_event_abi(self, chain_id, address, signature):
+
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         event_semantics = (
             semantics.contract.events.get(signature) if semantics else None
@@ -281,6 +297,10 @@ class SemanticsRepository:
 
     @lru_cache(maxsize=128)
     def get_transformations(self, chain_id, address, signature):
+
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         if semantics:
             transformations = semantics.contract.transformations.get(signature)
@@ -291,6 +311,10 @@ class SemanticsRepository:
 
     @lru_cache(maxsize=128)
     def get_anonymous_event_abi(self, chain_id, address):
+
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         event_semantics = None
         if semantics:
@@ -307,6 +331,10 @@ class SemanticsRepository:
 
     @lru_cache(maxsize=128)
     def get_function_abi(self, chain_id, address, signature):
+
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         function_semantics = (
             semantics.contract.functions.get(signature) if semantics else None
@@ -317,6 +345,9 @@ class SemanticsRepository:
     @lru_cache(maxsize=128)
     def get_constructor_abi(self, chain_id, address):
 
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         constructor_semantics = (
             semantics.contract.functions.get("constructor") if semantics else None
@@ -329,18 +360,29 @@ class SemanticsRepository:
         return constructor_semantics
 
     def get_address_label(self, chain_id, address, token_proxies=None):
-        semantics = self.get_semantics(chain_id, address)
-        if semantics.erc20:
-            contract_label = semantics.erc20.symbol
-        elif token_proxies and address in token_proxies:
-            contract_label = token_proxies[address][1] + "_proxy"
+
+        if not address:
+            return ''
+
+        if int(address, 16) in precompiles:
+            contract_label = 'Precompiled'
         else:
-            contract_label = semantics.name if semantics and semantics.name else address
+            semantics = self.get_semantics(chain_id, address)
+            if semantics.erc20:
+                contract_label = semantics.erc20.symbol
+            elif token_proxies and address in token_proxies:
+                contract_label = token_proxies[address][1] + "_proxy"
+            else:
+                contract_label = semantics.name if semantics and semantics.name else address
 
         return contract_label
 
     @lru_cache(maxsize=128)
     def check_is_contract(self, chain_id, address):
+
+        if not address:
+            return False
+
         semantics = self.get_semantics(chain_id, address)
         is_contract = semantics is not None and semantics.is_contract
 
@@ -348,6 +390,10 @@ class SemanticsRepository:
 
     @lru_cache(maxsize=128)
     def get_standard(self, chain_id, address):
+
+        if not address:
+            return None
+
         semantics = self.get_semantics(chain_id, address)
         standard = semantics.standard if semantics is not None else None
 
@@ -355,6 +401,9 @@ class SemanticsRepository:
 
     def get_token_data(self, chain_id, address, token_proxies=None):
 
+        if not address:
+            return None, None, None
+
         semantics = self.get_semantics(chain_id, address)
         if semantics and semantics.erc20:
             token_name = (
