@@ -205,7 +205,7 @@ class Web3Provider(NodeDataProvider):
             logs=_logs,
             logsBloom=raw_receipt.logsBloom,
             root=_root,
-            status=raw_receipt.status,
+            status=raw_receipt.get('status', True),
             to_address=raw_receipt.to,
             transactionHash=raw_receipt.transactionHash,
             transactionIndex=raw_receipt.transactionIndex,
@@ -241,7 +241,6 @@ class Web3Provider(NodeDataProvider):
         return code_hash
 
     # get the erc20 token data from the node
-    @lru_cache(maxsize=512)
     def get_erc20_token(
         self,
         token_address: str,
